pub struct OwnedMessage<Id> {
pub sender_id: Id,
pub opcode: u16,
pub args: SmallVec<[OwnedArgument<Id>; 4]>,
}Expand description
Represents a message that has been sent from some object.
Fields
sender_id: IdThe id of the object that sent the message.
opcode: u16The opcode of the message.
args: SmallVec<[OwnedArgument<Id>; 4]>The arguments of the message.